==> haskell-text-format-0.3.2-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-format
version:              0.3.2
visibility:           public
id:                   text-format-0.3.2-KZa9mcGxmQg9O58YI1MAN
key:                  text-format-0.3.2-KZa9mcGxmQg9O58YI1MAN
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  0a579fd0f6732ae85e0576ffecefdd48
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-8.10.2/site-local/text-format-0.3.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/text-format-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/text-format-0.3.2
hs-libraries:         HStext-format-0.3.2-KZa9mcGxmQg9O58YI1MAN
depends:
    array-0.5.4.0 base-4.14.1.0
    double-conversion-2.0.2.0-8V5aVluuLVpYtRSu8u6KZ ghc-prim-0.6.1
    integer-gmp-1.0.3.0 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    text-1.2.3.2 time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-format-0.3.2-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-format.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-format
version:              0.3.2
visibility:           public
id:                   text-format-0.3.2-DiR38qYFgOPGW0LzbyfsJZ
key:                  text-format-0.3.2-DiR38qYFgOPGW0LzbyfsJZ
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/bos/text-format
synopsis:             Text formatting
description:
    A text formatting library optimized for both ease of use and high
    performance.

category:             Text
abi:                  527ce3a9042f58a221ebdf9bd2897820
exposed:              True
exposed-modules:
    Data.Text.Buildable Data.Text.Format Data.Text.Format.Params
    Data.Text.Format.Types Data.Text.Format.Types.Internal

hidden-modules:       Data.Text.Format.Functions Data.Text.Format.Int
import-dirs:          /usr/lib/ghc-8.10.2/site-local/text-format-0.3.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/text-format-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/text-format-0.3.2
hs-libraries:         HStext-format-0.3.2-DiR38qYFgOPGW0LzbyfsJZ
depends:
    array-0.5.4.0 base-4.14.1.0
    double-conversion-2.0.2.0-Kren3KgByJC3XBdvUn445m ghc-prim-0.6.1
    integer-gmp-1.0.3.0 old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    text-1.2.3.2 time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-text-format/html/text-format.haddock
haddock-html:         /usr/share/doc/haskell-text-format/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
